import { defineStore } from 'pinia';
import { getAuthButtonListApi, getAuthMenuListApi, getAuthRoleListApi } from '@/api/modules/system/login';
import { getAllBreadcrumbList, getFlatMenuList, getShowMenuList } from '@/utils';
import { computed, ref } from 'vue';

export const useAuthStore = defineStore('auth', () => {
  const isLoaded = ref(false);
  // 按钮权限列表
  const authButtonList = ref<string[]>([]);
  // 菜单权限列表
  const authMenuList = ref<Menu.MenuOptions[]>([]);
  // 用户角色列表. 以后如有业务需要可结合此属性灵活处理
  const authRoleList = ref<string[]>([]);
  // 当前页面的 router name，用来做按钮权限筛选
  const routeName = ref('');

  // 按钮权限列表
  const authButtonListGet = computed(() => authButtonList.value);
  // 菜单权限列表 ==> 这里的菜单没有经过任何处理
  const authMenuListGet = computed(() => authMenuList.value);
  // 用户角色列表
  const authRoleListGet = computed(() => authRoleList.value);
  // 菜单权限列表 ==> 左侧菜单栏渲染，需要剔除 isHidden == true
  const showMenuListGet = computed(() => getShowMenuList(authMenuList.value));
  // 菜单权限列表 ==> 扁平化之后的一维数组菜单，主要用来添加动态路由
  const flatMenuListGet = computed(() => getFlatMenuList(authMenuList.value));
  // 递归处理后的所有面包屑导航列表
  const breadcrumbListGet = computed(() => getAllBreadcrumbList(authMenuList.value));

  // Get AuthButtonList
  async function getAuthButtonList() {
    const { data } = await getAuthButtonListApi();
    // const data = [
    //   "sys.user.query_table",
    //   "sys.user.create_btn",
    //   "sys.user.update_btn",
    //   "sys.user.delete_btn",
    //   "sys.user.role_set_btn",
    //   "sys.user.unlock_btn",
    //   "sys.user_resetPwd",
    //   "sys.user.dept_set_btn",
    //   "sys.role.query_table",
    //   "sys.role.create_btn",
    //   "sys.role.update_btn",
    //   "sys.role.delete_btn",
    //   "sys.role.setting_btn",
    //   "sys.menu.query_table",
    //   "sys.menu.create_btn",
    //   "sys.menu.update_btn",
    //   "sys.menu.delete_btn",
    //   "sys.menu.sql_btn",
    //   "sys.dict.query_table",
    //   "sys.dict.add_type_btn",
    //   "sys.dict.update_type_btn",
    //   "sys.dict.delete_type_btn",
    //   "sys.dict.add_btn",
    //   "sys.dict.update_btn",
    //   "sys.dict.delete_btn",
    //   "sys.config.query_table",
    //   "sys.config.add_btn",
    //   "sys.config.update_btn",
    //   "sys.config.delete_btn",
    //   "sys.client.query_table",
    //   "sys.client.create",
    //   "sys.client.update",
    //   "sys.client.remove",
    //   "sys.dept.query_table",
    //   "sys.dept.create",
    //   "sys.dept.update",
    //   "sys.dept.remove",
    //   "teacher.statistics.query_table",
    //   "teacher.statistics.create",
    //   "teacher.statistics.update",
    //   "teacher.statistics.remove",
    //   "teacher.statistics.import",
    //   "teacher.statistics.export",
    //   "generator.list",
    //   "generator.import",
    //   "generator.update",
    //   "generator.generator",
    //   "generator.remove",
    //   "generator.zip",
    //   "generator.preview",
    //   "sys.user.data_role_set_btn",
    //   "sys.data.role.query_table",
    //   "sys.data.role.create",
    //   "sys.data.role.update",
    //   "sys.data.role.remove",
    //   "sys.dict.sql_btn",
    //   "sys.file.query_table",
    //   "sys.file.create",
    //   "sys.file.update",
    //   "sys.file.remove",
    //   "sys.temp.file.query_table",
    //   "sys.temp.file.create",
    //   "sys.temp.file.update",
    //   "sys.temp.file.remove"
    // ]
    authButtonList.value = data;
  }

  // Get AuthMenuList
  async function getAuthMenuList() {
    // const { data } = await getAuthMenuListApi();

    const data = [
      {
        "id": "88b2e5def2ff474fa8bf3537d4a2fe5b",
        "pid": "0",
        "path": "/system",
        "name": "system",
        "sort": 300,
        "component": "",
        "meta": {
          "icon": "Tools",
          "title": "系统管理",
          "isLink": "",
          "isHidden": "F",
          "isFull": "F",
          "isAffix": "F",
          "isKeepAlive": "T",
          "useDataScope": "F"
        },
        "children": [
          {
            "id": "140c9ed43ef54542bbcdde8a5d928400",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/accountManage",
            "name": "accountManage",
            "sort": 100,
            "component": "/system/accountManage/index",
            "meta": {
              "icon": "UserFilled",
              "title": "账号管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "T",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.user.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "c6dd479d5b304731be403d7551c60d70",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/roleManage",
            "name": "roleManage",
            "sort": 200,
            "component": "/system/roleManage/index",
            "meta": {
              "icon": "User",
              "title": "角色管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "T",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.role.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "99c2ee7b882749e597bcd62385f368fb",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/menuMange",
            "name": "menuMange",
            "sort": 300,
            "component": "/system/menuMange/index",
            "meta": {
              "icon": "Menu",
              "title": "菜单管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "T",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.menu.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "dcb6aabcd910469ebf3efbc7e43282d4",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/dictManage",
            "name": "dictManage",
            "sort": 400,
            "component": "/system/dictManage/index",
            "meta": {
              "icon": "Reading",
              "title": "字典管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "T",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.dict.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "29d33eba6b73420287d8f7e64aea62b3",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/configManage",
            "name": "configManage",
            "sort": 500,
            "component": "/system/configManage/index",
            "meta": {
              "icon": "Key",
              "title": "参数管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "T",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.config.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "9e731ff422184fc1be2022c5c985735e",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/clientManage",
            "name": "ClientManageView",
            "sort": 600,
            "component": "/system/clientManage/index",
            "meta": {
              "icon": "Operation",
              "title": "客户端管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "F",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.client.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "8354d626cc65487594a7c38e98de1bad",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/deptManage",
            "name": "SysDeptView",
            "sort": 700,
            "component": "/system/deptManage/index",
            "meta": {
              "icon": "svg-org",
              "title": "部门管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "F",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.dept.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "0444cd2c01584f0687264b6205536691",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/dataRoleManage",
            "name": "SysDataRoleView",
            "sort": 800,
            "component": "/system/dataRoleManage/index",
            "meta": {
              "icon": "svg-scope",
              "title": "数据权限",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "F",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.data.role.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "c4896e8735a745bda9b47ecaf50f46f2",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/fileManage",
            "name": "SysFileView",
            "sort": 900,
            "component": "/system/fileManage/index",
            "meta": {
              "icon": "Files",
              "title": "文件管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "F",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.file.query_table",
            "menuTypeCd": "1002002"
          },
          {
            "id": "8231a369712e4f8f8ac09fce232cd034",
            "pid": "88b2e5def2ff474fa8bf3537d4a2fe5b",
            "path": "/system/sysTempFile",
            "name": "SysTempFileView",
            "sort": 1000,
            "component": "/system/sysTempFile/index",
            "meta": {
              "icon": "DocumentCopy",
              "title": "模版文件管理",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "F",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "sys.temp.file.query_table",
            "menuTypeCd": "1002002"
          }
        ],
        "permissions": "",
        "menuTypeCd": "1002001"
      },
      {
        "id": "da1b46db642f42978f83ed5eb34870ce",
        "pid": "0",
        "path": "/toolbox",
        "name": "toolbox",
        "sort": 200,
        "component": "",
        "meta": {
          "icon": "Briefcase",
          "title": "工具箱",
          "isLink": "",
          "isHidden": "F",
          "isFull": "F",
          "isAffix": "F",
          "isKeepAlive": "F",
          "useDataScope": "F"
        },
        "children": [
          {
            "id": "0e529e8a9dbf450898b695e051c36d48",
            "pid": "da1b46db642f42978f83ed5eb34870ce",
            "path": "/toolbox/generator",
            "name": "generator",
            "sort": 100,
            "component": "/toolbox/generator/index",
            "meta": {
              "icon": "Brush",
              "title": "代码生成",
              "isLink": "",
              "isHidden": "F",
              "isFull": "F",
              "isAffix": "F",
              "isKeepAlive": "F",
              "useDataScope": "F"
            },
            "children": [],
            "permissions": "generator.list",
            "menuTypeCd": "1002002"
          }
        ],
        "permissions": "",
        "menuTypeCd": "1002001"
      },
      {
        "id": "85b54322630f43a39296488a5e76ba16",
        "pid": "0",
        "path": "/teacher/teacherStatistics",
        "name": "TeacherStatisticsView",
        "sort": 400,
        "component": "/teacher/teacherStatistics/index",
        "meta": {
          "icon": "svg-org",
          "title": "教师统计",
          "isLink": "",
          "isHidden": "F",
          "isFull": "F",
          "isAffix": "F",
          "isKeepAlive": "F",
          "useDataScope": "T"
        },
        "children": [],
        "permissions": "teacher.statistics.query_table",
        "menuTypeCd": "1002002"
      }
    ]
    authMenuList.value = data;

    const beforeMenuList: Menu.MenuOptions[] = [
      {
        id: 'b6c6433509ab405f94796cc93752d417',
        pid: '0',
        path: '/system/message',
        name: 'Message',
        sort: 1,
        component: '/system/message/index',
        meta: {
          icon: 'Bell',
          title: '消息',
          isLink: '',
          isHidden: 'F',
          isFull: 'F',
          isAffix: 'F',
          isKeepAlive: 'F',
          useDataScope: 'F'
        },
        children: [],
        permissions: '',
        menuTypeCd: '1002002'
      },
      {
        id: '6abae64123b746808837ae61bf8d08fb',
        pid: '0',
        path: '/system/message/:id',
        name: 'MessagePopup',
        sort: 2,
        component: '/system/message/index',
        meta: {
          icon: 'Bell',
          title: '消息详情',
          isLink: '',
          isHidden: 'T',
          isFull: 'F',
          isAffix: 'F',
          isKeepAlive: 'F',
          useDataScope: 'F'
        },
        children: [],
        permissions: '',
        menuTypeCd: '1002002'
      }
    ];
    authMenuList.value.unshift(...beforeMenuList);

    const afterMenuList: Menu.MenuOptions[] = [
      {
        id: 'c6328b228c2c4e6bb5b1beb83110dcfa',
        pid: '0',
        path: '/demo',
        name: 'demo',
        sort: 500,
        component: '/demo/index',
        meta: {
          icon: 'Flag',
          title: '功能演示',
          isLink: '',
          isHidden: 'F',
          isFull: 'F',
          isAffix: 'F',
          isKeepAlive: 'F',
          useDataScope: 'F'
        },
        children: [],
        permissions: '',
        menuTypeCd: '1002002'
      },
      {
        id: 'c0a0eba2922346b0b8ae9d4dd951498e',
        pid: '0',
        path: '/about/index',
        name: 'about',
        sort: 600,
        component: '/about/index',
        meta: {
          icon: 'InfoFilled',
          title: '关于项目',
          isLink: '',
          isHidden: 'F',
          isFull: 'F',
          isAffix: 'F',
          isKeepAlive: 'F',
          useDataScope: 'F'
        },
        children: [],
        permissions: '',
        menuTypeCd: '1002002'
      }
    ];
    authMenuList.value.push(...afterMenuList);
  }

  // Get AuthRoleList
  async function getAuthRoleList() {
    const { data } = await getAuthRoleListApi();
    // const data = ["admin"];
    authRoleList.value = data;
  }

  function clear() {
    isLoaded.value = false;
    authMenuList.value = [];
    authButtonList.value = [];
    authRoleList.value = [];
  }

  // Set RouteName
  async function setRouteName(name: string) {
    routeName.value = name;
  }

  async function setLoaded() {
    isLoaded.value = true;
  }

  return {
    isLoaded,
    setLoaded,
    routeName,
    authButtonListGet,
    authMenuListGet,
    authRoleListGet,
    showMenuListGet,
    flatMenuListGet,
    breadcrumbListGet,
    getAuthButtonList,
    getAuthMenuList,
    getAuthRoleList,
    setRouteName,
    clear
  };
});
